==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/GetVirtualHubRouteTableV2PlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.GetVirtualHubRouteTableV2PlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The resource group name of the VirtualHubRouteTableV2.
 * @property routeTableName The name of the VirtualHubRouteTableV2.
 * @property virtualHubName The name of the VirtualHub.
 */
public data class GetVirtualHubRouteTableV2PlainArgs(
    public val resourceGroupName: String,
    public val routeTableName: String,
    public val virtualHubName: String,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.GetVirtualHubRouteTableV2PlainArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.GetVirtualHubRouteTableV2PlainArgs =
        com.pulumi.azurenative.network.inputs.GetVirtualHubRouteTableV2PlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .routeTableName(routeTableName.let({ args0 -> args0 }))
            .virtualHubName(virtualHubName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetVirtualHubRouteTableV2PlainArgs].
 */
@PulumiTagMarker
public class GetVirtualHubRouteTableV2PlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var routeTableName: String? = null

    private var virtualHubName: String? = null

    /**
     * @param value The resource group name of the VirtualHubRouteTableV2.
     */
    @JvmName("femdbpwewshgvanx")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the VirtualHubRouteTableV2.
     */
    @JvmName("msbjhcsrmwrlrtnp")
    public suspend fun routeTableName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.routeTableName = mapped
    }

    /**
     * @param value The name of the VirtualHub.
     */
    @JvmName("mqvhwwgvalqiocxx")
    public suspend fun virtualHubName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.virtualHubName = mapped
    }

    internal fun build(): GetVirtualHubRouteTableV2PlainArgs = GetVirtualHubRouteTableV2PlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        routeTableName = routeTableName ?: throw PulumiNullFieldException("routeTableName"),
        virtualHubName = virtualHubName ?: throw PulumiNullFieldException("virtualHubName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/GetVirtualHubRouteTableV2PlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.GetVirtualHubRouteTableV2PlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The resource group name of the VirtualHubRouteTableV2.
 * @property routeTableName The name of the VirtualHubRouteTableV2.
 * @property virtualHubName The name of the VirtualHub.
 */
public data class GetVirtualHubRouteTableV2PlainArgs(
    public val resourceGroupName: String,
    public val routeTableName: String,
    public val virtualHubName: String,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.GetVirtualHubRouteTableV2PlainArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.GetVirtualHubRouteTableV2PlainArgs =
        com.pulumi.azurenative.network.inputs.GetVirtualHubRouteTableV2PlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .routeTableName(routeTableName.let({ args0 -> args0 }))
            .virtualHubName(virtualHubName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetVirtualHubRouteTableV2PlainArgs].
 */
@PulumiTagMarker
public class GetVirtualHubRouteTableV2PlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var routeTableName: String? = null

    private var virtualHubName: String? = null

    /**
     * @param value The resource group name of the VirtualHubRouteTableV2.
     */
    @JvmName("niubinejmvmaygxk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the VirtualHubRouteTableV2.
     */
    @JvmName("vmcekhhwqpmkynht")
    public suspend fun routeTableName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.routeTableName = mapped
    }

    /**
     * @param value The name of the VirtualHub.
     */
    @JvmName("qbscyswifkxfxvbp")
    public suspend fun virtualHubName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.virtualHubName = mapped
    }

    internal fun build(): GetVirtualHubRouteTableV2PlainArgs = GetVirtualHubRouteTableV2PlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        routeTableName = routeTableName ?: throw PulumiNullFieldException("routeTableName"),
        virtualHubName = virtualHubName ?: throw PulumiNullFieldException("virtualHubName"),
    )
}
